# Hegel

> [!IMPORTANT]
> If you've found this repository, congratulations! You're getting a sneak peak at an upcoming property-based testing library from [Antithesis](https://antithesis.com/), built on [Hypothesis](https://hypothesis.works/).
>
> We are still making rapid changes and progress.  Feel free to experiment, but don't expect stability from Hegel just yet!

The Hegel server. Provides communication to the backing Hypothesis library over a socket.

## Hegel libraries

- [Python](https://github.com/hegeldev/hegel-python)
- [Go](https://github.com/hegeldev/hegel-go)
- [Rust](https://github.com/hegeldev/hegel-rust)

## Development

```bash
just setup     # install dependencies
just test      # run tests
just format    # run formatter
just check     # run PR checks: lint + tests + docs
```
